@@ -31,11 +31,13 @@ from gvm.protocols.gmpv8.types import (
     InfoType,
     PermissionSubjectType,
     PortRangeType,
+    ReportFormatType,
     SeverityLevel,
     SnmpAuthAlgorithm,
     SnmpPrivacyAlgorithm,
     TicketStatus,
     TimeUnit,
+    UserAuthType,
     get_alive_test_from_string,
     get_asset_type_from_string,
     get_credential_format_from_string,
@@ -45,11 +47,13 @@ from gvm.protocols.gmpv8.types import (
     get_info_type_from_string,
     get_permission_subject_type_from_string,
     get_port_range_type_from_string,
+    get_report_format_id_from_string,
     get_severity_level_from_string,
     get_snmp_auth_algorithm_from_string,
     get_snmp_privacy_algorithm_from_string,
     get_ticket_status_from_string,
     get_time_unit_from_string,
+    get_user_auth_type_from_string,
 )
 
 
@@ -68,12 +72,14 @@ __all__ = [
     "InfoType",
     "PermissionSubjectType",
     "PortRangeType",
+    "ReportFormatType",
     "ScannerType",
     "SeverityLevel",
     "SnmpAuthAlgorithm",
     "SnmpPrivacyAlgorithm",
     "TicketStatus",
     "TimeUnit",
+    "UserAuthType",
     "get_alert_condition_from_string",
     "get_alert_event_from_string",
     "get_alert_method_from_string",
@@ -88,12 +94,14 @@ __all__ = [
     "get_info_type_from_string",
     "get_permission_subject_type_from_string",
     "get_port_range_type_from_string",
+    "get_report_format_id_from_string",
     "get_scanner_type_from_string",
     "get_severity_level_from_string",
     "get_snmp_auth_algorithm_from_string",
     "get_snmp_privacy_algorithm_from_string",
     "get_ticket_status_from_string",
     "get_time_unit_from_string",
+    "get_user_auth_type_from_string",
 ]
 
 
